# ds_tut

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Some basic infrastructure for a [Data Science
Tutorial](https://github.com/ephes/data_science_tutorial)

## Install

``` sh
pip install ds_tut
```

## Install Development Version

``` sh
git clone https://github.com/ephes/ds_tut
cd ds_tut
python -m pip install -e ".[dev]"
```

## How to use

### Download Datasets

``` python
from pathlib import Path

archive_name = "reuters21578.tar.gz"
training_data_url = "http://www.daviddlewis.com/resources/testcollections/reuters21578/{}".format(archive_name)
data_root = Path.cwd() / "data"
training_data_path = data_root / archive_name
data_size = download_from_url(training_data_url, training_data_path)
print(data_size)
```

    8150596
